<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>osd::DisPlayModeApplet</name>
    <message>
        <source>Duplicate</source>
        <translation>Дублювати</translation>
    </message>
    <message>
        <source>Extend</source>
        <translation>Розширити</translation>
    </message>
    <message>
        <source>Only on %1</source>
        <translation>Лише на %1</translation>
    </message>
</context>
</TS>